import { HttpRequest, QueryParameterBag } from "@smithy/types";
/**
 * @internal
 */
export declare const cloneRequest: ({ headers, query, ...rest }: HttpRequest) => HttpRequest;
export declare const cloneQuery: (query: QueryParameterBag) => QueryParameterBag;
