import { HttpRequest, QueryParameterBag } from "@smithy/types";
/**
 * @private
 */
export declare const moveHeadersToQuery: (request: HttpRequest, options?: {
    unhoistableHeaders?: Set<string>;
}) => HttpRequest & {
    query: QueryParameterBag;
};
