import { HeaderBag, HttpRequest } from "@smithy/types";
/**
 * @private
 */
export declare const getCanonicalHeaders: ({ headers }: HttpRequest, unsignableHeaders?: Set<string>, signableHeaders?: Set<string>) => HeaderBag;
