import { ChecksumConstructor, HashConstructor, HttpRequest } from "@smithy/types";
/**
 * @private
 */
export declare const getPayloadHash: ({ headers, body }: HttpRequest, hashConstructor: ChecksumConstructor | HashConstructor) => Promise<string>;
