import { HeaderBag } from "@smithy/types";
export declare const hasHeader: (soughtHeader: string, headers: HeaderBag) => boolean;
export declare const getHeaderValue: (soughtHeader: string, headers: HeaderBag) => string | undefined;
export declare const deleteHeader: (soughtHeader: string, headers: HeaderBag) => void;
